==> ignite-core-2.7.0-sources.jar: org/apache/ignite/internal/processors/platform/client/cache/ClientCacheNodePartitionsResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.platform.client.cache;

import java.util.Collection;
import org.apache.ignite.internal.binary.BinaryRawWriterEx;
import org.apache.ignite.internal.processors.odbc.ClientConnectableNodePartitions;
import org.apache.ignite.internal.processors.platform.client.ClientResponse;

/**
 * Client cache nodes partitions response.
 */
class ClientCacheNodePartitionsResponse extends ClientResponse {
    /** Node partitions. */
    private final Collection<ClientConnectableNodePartitions> nodeParts;

    /**
     * @param requestId Request id.
     * @param nodeParts Node partitions info.
     */
    ClientCacheNodePartitionsResponse(long requestId, Collection<ClientConnectableNodePartitions> nodeParts) {
        super(requestId);

        assert nodeParts != null;

        this.nodeParts = nodeParts;
    }

    /** {@inheritDoc} */
    @Override public void encode(BinaryRawWriterEx writer) {
        super.encode(writer);

        writer.writeInt(nodeParts.size());

        for (ClientConnectableNodePartitions nodePart : nodeParts) {
            nodePart.write(writer);
        }
    }
}

==> ignite-core-8.8.18-sources.jar: org/apache/ignite/internal/processors/platform/client/cache/ClientCacheNodePartitionsResponse.java <==
/*
 * Copyright 2019 GridGain Systems, Inc. and Contributors.
 *
 * Licensed under the GridGain Community Edition License (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.gridgain.com/products/software/community-edition/gridgain-community-edition-license
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.processors.platform.client.cache;

import java.util.Collection;
import org.apache.ignite.internal.binary.BinaryRawWriterEx;
import org.apache.ignite.internal.processors.platform.client.ClientConnectableNodePartitions;
import org.apache.ignite.internal.processors.platform.client.ClientConnectionContext;
import org.apache.ignite.internal.processors.platform.client.ClientResponse;

/**
 * Client cache nodes partitions response.
 * Deprecated since 1.3.0. Replaced with {@link ClientCachePartitionsResponse}.
 */
class ClientCacheNodePartitionsResponse extends ClientResponse {
    /** Node partitions. */
    private final Collection<ClientConnectableNodePartitions> nodeParts;

    /**
     * @param requestId Request id.
     * @param nodeParts Node partitions info.
     */
    ClientCacheNodePartitionsResponse(long requestId, Collection<ClientConnectableNodePartitions> nodeParts) {
        super(requestId);

        assert nodeParts != null;

        this.nodeParts = nodeParts;
    }

    /** {@inheritDoc} */
    @Override public void encode(ClientConnectionContext ctx, BinaryRawWriterEx writer) {
        super.encode(ctx, writer);

        writer.writeInt(nodeParts.size());

        for (ClientConnectableNodePartitions nodePart : nodeParts) {
            nodePart.write(writer);
        }
    }
}
